summaryrefslogtreecommitdiffstats
path: root/vendor/stripe/stripe-php/lib/Service/Terminal
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/stripe/stripe-php/lib/Service/Terminal')
-rw-r--r--vendor/stripe/stripe-php/lib/Service/Terminal/ConfigurationService.php86
-rw-r--r--vendor/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php50
-rw-r--r--vendor/stripe/stripe-php/lib/Service/Terminal/LocationService.php176
-rw-r--r--vendor/stripe/stripe-php/lib/Service/Terminal/ReaderService.php238
-rw-r--r--vendor/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php60
5 files changed, 382 insertions, 228 deletions
diff --git a/vendor/stripe/stripe-php/lib/Service/Terminal/ConfigurationService.php b/vendor/stripe/stripe-php/lib/Service/Terminal/ConfigurationService.php
new file mode 100644
index 0000000..733d3cc
--- /dev/null
+++ b/vendor/stripe/stripe-php/lib/Service/Terminal/ConfigurationService.php
@@ -0,0 +1,86 @@
+<?php
+
+// File generated from our OpenAPI spec
+
+namespace Stripe\Service\Terminal;
+
+class ConfigurationService extends \Stripe\Service\AbstractService
+{
+ /**
+ * Returns a list of <code>Configuration</code> objects.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Collection<\Stripe\Terminal\Configuration>
+ */
+ public function all($params = null, $opts = null)
+ {
+ return $this->requestCollection('get', '/v1/terminal/configurations', $params, $opts);
+ }
+
+ /**
+ * Creates a new <code>Configuration</code> object.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Configuration
+ */
+ public function create($params = null, $opts = null)
+ {
+ return $this->request('post', '/v1/terminal/configurations', $params, $opts);
+ }
+
+ /**
+ * Deletes a <code>Configuration</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Configuration
+ */
+ public function delete($id, $params = null, $opts = null)
+ {
+ return $this->request('delete', $this->buildPath('/v1/terminal/configurations/%s', $id), $params, $opts);
+ }
+
+ /**
+ * Retrieves a <code>Configuration</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Configuration
+ */
+ public function retrieve($id, $params = null, $opts = null)
+ {
+ return $this->request('get', $this->buildPath('/v1/terminal/configurations/%s', $id), $params, $opts);
+ }
+
+ /**
+ * Updates a new <code>Configuration</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Configuration
+ */
+ public function update($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/configurations/%s', $id), $params, $opts);
+ }
+}
diff --git a/vendor/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php b/vendor/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php
index 7b25b23..db2ef9a 100644
--- a/vendor/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php
+++ b/vendor/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php
@@ -1,25 +1,25 @@
-<?php
-
-// File generated from our OpenAPI spec
-
-namespace Stripe\Service\Terminal;
-
-class ConnectionTokenService extends \Stripe\Service\AbstractService
-{
- /**
- * To connect to a reader the Stripe Terminal SDK needs to retrieve a short-lived
- * connection token from Stripe, proxied through your server. On your backend, add
- * an endpoint that creates and returns a connection token.
- *
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\ConnectionToken
- */
- public function create($params = null, $opts = null)
- {
- return $this->request('post', '/v1/terminal/connection_tokens', $params, $opts);
- }
-}
+<?php
+
+// File generated from our OpenAPI spec
+
+namespace Stripe\Service\Terminal;
+
+class ConnectionTokenService extends \Stripe\Service\AbstractService
+{
+ /**
+ * To connect to a reader the Stripe Terminal SDK needs to retrieve a short-lived
+ * connection token from Stripe, proxied through your server. On your backend, add
+ * an endpoint that creates and returns a connection token.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\ConnectionToken
+ */
+ public function create($params = null, $opts = null)
+ {
+ return $this->request('post', '/v1/terminal/connection_tokens', $params, $opts);
+ }
+}
diff --git a/vendor/stripe/stripe-php/lib/Service/Terminal/LocationService.php b/vendor/stripe/stripe-php/lib/Service/Terminal/LocationService.php
index 8adc7a5..456a5a7 100644
--- a/vendor/stripe/stripe-php/lib/Service/Terminal/LocationService.php
+++ b/vendor/stripe/stripe-php/lib/Service/Terminal/LocationService.php
@@ -1,87 +1,89 @@
-<?php
-
-// File generated from our OpenAPI spec
-
-namespace Stripe\Service\Terminal;
-
-class LocationService extends \Stripe\Service\AbstractService
-{
- /**
- * Returns a list of <code>Location</code> objects.
- *
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Collection
- */
- public function all($params = null, $opts = null)
- {
- return $this->requestCollection('get', '/v1/terminal/locations', $params, $opts);
- }
-
- /**
- * Creates a new <code>Location</code> object.
- *
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Location
- */
- public function create($params = null, $opts = null)
- {
- return $this->request('post', '/v1/terminal/locations', $params, $opts);
- }
-
- /**
- * Deletes a <code>Location</code> object.
- *
- * @param string $id
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Location
- */
- public function delete($id, $params = null, $opts = null)
- {
- return $this->request('delete', $this->buildPath('/v1/terminal/locations/%s', $id), $params, $opts);
- }
-
- /**
- * Retrieves a <code>Location</code> object.
- *
- * @param string $id
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Location
- */
- public function retrieve($id, $params = null, $opts = null)
- {
- return $this->request('get', $this->buildPath('/v1/terminal/locations/%s', $id), $params, $opts);
- }
-
- /**
- * Updates a <code>Location</code> object by setting the values of the parameters
- * passed. Any parameters not provided will be left unchanged.
- *
- * @param string $id
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Location
- */
- public function update($id, $params = null, $opts = null)
- {
- return $this->request('post', $this->buildPath('/v1/terminal/locations/%s', $id), $params, $opts);
- }
-}
+<?php
+
+// File generated from our OpenAPI spec
+
+namespace Stripe\Service\Terminal;
+
+class LocationService extends \Stripe\Service\AbstractService
+{
+ /**
+ * Returns a list of <code>Location</code> objects.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Collection<\Stripe\Terminal\Location>
+ */
+ public function all($params = null, $opts = null)
+ {
+ return $this->requestCollection('get', '/v1/terminal/locations', $params, $opts);
+ }
+
+ /**
+ * Creates a new <code>Location</code> object. For further details, including which
+ * address fields are required in each country, see the <a
+ * href="/docs/terminal/fleet/locations">Manage locations</a> guide.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Location
+ */
+ public function create($params = null, $opts = null)
+ {
+ return $this->request('post', '/v1/terminal/locations', $params, $opts);
+ }
+
+ /**
+ * Deletes a <code>Location</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Location
+ */
+ public function delete($id, $params = null, $opts = null)
+ {
+ return $this->request('delete', $this->buildPath('/v1/terminal/locations/%s', $id), $params, $opts);
+ }
+
+ /**
+ * Retrieves a <code>Location</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Location
+ */
+ public function retrieve($id, $params = null, $opts = null)
+ {
+ return $this->request('get', $this->buildPath('/v1/terminal/locations/%s', $id), $params, $opts);
+ }
+
+ /**
+ * Updates a <code>Location</code> object by setting the values of the parameters
+ * passed. Any parameters not provided will be left unchanged.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Location
+ */
+ public function update($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/locations/%s', $id), $params, $opts);
+ }
+}
diff --git a/vendor/stripe/stripe-php/lib/Service/Terminal/ReaderService.php b/vendor/stripe/stripe-php/lib/Service/Terminal/ReaderService.php
index 765015c..2f228f2 100644
--- a/vendor/stripe/stripe-php/lib/Service/Terminal/ReaderService.php
+++ b/vendor/stripe/stripe-php/lib/Service/Terminal/ReaderService.php
@@ -1,87 +1,151 @@
-<?php
-
-// File generated from our OpenAPI spec
-
-namespace Stripe\Service\Terminal;
-
-class ReaderService extends \Stripe\Service\AbstractService
-{
- /**
- * Returns a list of <code>Reader</code> objects.
- *
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Collection
- */
- public function all($params = null, $opts = null)
- {
- return $this->requestCollection('get', '/v1/terminal/readers', $params, $opts);
- }
-
- /**
- * Creates a new <code>Reader</code> object.
- *
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Reader
- */
- public function create($params = null, $opts = null)
- {
- return $this->request('post', '/v1/terminal/readers', $params, $opts);
- }
-
- /**
- * Deletes a <code>Reader</code> object.
- *
- * @param string $id
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Reader
- */
- public function delete($id, $params = null, $opts = null)
- {
- return $this->request('delete', $this->buildPath('/v1/terminal/readers/%s', $id), $params, $opts);
- }
-
- /**
- * Retrieves a <code>Reader</code> object.
- *
- * @param string $id
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Reader
- */
- public function retrieve($id, $params = null, $opts = null)
- {
- return $this->request('get', $this->buildPath('/v1/terminal/readers/%s', $id), $params, $opts);
- }
-
- /**
- * Updates a <code>Reader</code> object by setting the values of the parameters
- * passed. Any parameters not provided will be left unchanged.
- *
- * @param string $id
- * @param null|array $params
- * @param null|array|\Stripe\Util\RequestOptions $opts
- *
- * @throws \Stripe\Exception\ApiErrorException if the request fails
- *
- * @return \Stripe\Terminal\Reader
- */
- public function update($id, $params = null, $opts = null)
- {
- return $this->request('post', $this->buildPath('/v1/terminal/readers/%s', $id), $params, $opts);
- }
-}
+<?php
+
+// File generated from our OpenAPI spec
+
+namespace Stripe\Service\Terminal;
+
+class ReaderService extends \Stripe\Service\AbstractService
+{
+ /**
+ * Returns a list of <code>Reader</code> objects.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Collection<\Stripe\Terminal\Reader>
+ */
+ public function all($params = null, $opts = null)
+ {
+ return $this->requestCollection('get', '/v1/terminal/readers', $params, $opts);
+ }
+
+ /**
+ * Cancels the current reader action.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function cancelAction($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/readers/%s/cancel_action', $id), $params, $opts);
+ }
+
+ /**
+ * Creates a new <code>Reader</code> object.
+ *
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function create($params = null, $opts = null)
+ {
+ return $this->request('post', '/v1/terminal/readers', $params, $opts);
+ }
+
+ /**
+ * Deletes a <code>Reader</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function delete($id, $params = null, $opts = null)
+ {
+ return $this->request('delete', $this->buildPath('/v1/terminal/readers/%s', $id), $params, $opts);
+ }
+
+ /**
+ * Initiates a payment flow on a Reader.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function processPaymentIntent($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/readers/%s/process_payment_intent', $id), $params, $opts);
+ }
+
+ /**
+ * Initiates a setup intent flow on a Reader.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function processSetupIntent($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/readers/%s/process_setup_intent', $id), $params, $opts);
+ }
+
+ /**
+ * Retrieves a <code>Reader</code> object.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function retrieve($id, $params = null, $opts = null)
+ {
+ return $this->request('get', $this->buildPath('/v1/terminal/readers/%s', $id), $params, $opts);
+ }
+
+ /**
+ * Sets reader display to show cart details.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function setReaderDisplay($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/readers/%s/set_reader_display', $id), $params, $opts);
+ }
+
+ /**
+ * Updates a <code>Reader</code> object by setting the values of the parameters
+ * passed. Any parameters not provided will be left unchanged.
+ *
+ * @param string $id
+ * @param null|array $params
+ * @param null|array|\Stripe\Util\RequestOptions $opts
+ *
+ * @throws \Stripe\Exception\ApiErrorException if the request fails
+ *
+ * @return \Stripe\Terminal\Reader
+ */
+ public function update($id, $params = null, $opts = null)
+ {
+ return $this->request('post', $this->buildPath('/v1/terminal/readers/%s', $id), $params, $opts);
+ }
+}
diff --git a/vendor/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php b/vendor/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php
index c70ac87..13ab144 100644
--- a/vendor/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php
+++ b/vendor/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php
@@ -1,29 +1,31 @@
-<?php
-
-// File generated from our OpenAPI spec
-
-namespace Stripe\Service\Terminal;
-
-/**
- * Service factory class for API resources in the Terminal namespace.
- *
- * @property ConnectionTokenService $connectionTokens
- * @property LocationService $locations
- * @property ReaderService $readers
- */
-class TerminalServiceFactory extends \Stripe\Service\AbstractServiceFactory
-{
- /**
- * @var array<string, string>
- */
- private static $classMap = [
- 'connectionTokens' => ConnectionTokenService::class,
- 'locations' => LocationService::class,
- 'readers' => ReaderService::class,
- ];
-
- protected function getServiceClass($name)
- {
- return \array_key_exists($name, self::$classMap) ? self::$classMap[$name] : null;
- }
-}
+<?php
+
+// File generated from our OpenAPI spec
+
+namespace Stripe\Service\Terminal;
+
+/**
+ * Service factory class for API resources in the Terminal namespace.
+ *
+ * @property ConfigurationService $configurations
+ * @property ConnectionTokenService $connectionTokens
+ * @property LocationService $locations
+ * @property ReaderService $readers
+ */
+class TerminalServiceFactory extends \Stripe\Service\AbstractServiceFactory
+{
+ /**
+ * @var array<string, string>
+ */
+ private static $classMap = [
+ 'configurations' => ConfigurationService::class,
+ 'connectionTokens' => ConnectionTokenService::class,
+ 'locations' => LocationService::class,
+ 'readers' => ReaderService::class,
+ ];
+
+ protected function getServiceClass($name)
+ {
+ return \array_key_exists($name, self::$classMap) ? self::$classMap[$name] : null;
+ }
+}